@@ -1,13 +1,14 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import fields, pre_dump
 
 from flag_engine.environments.integrations.schemas import IntegrationSchema
 from flag_engine.environments.models import EnvironmentModel
 from flag_engine.features.schemas import FeatureStateSchema
 from flag_engine.projects.schemas import ProjectSchema
-from flag_engine.utils.fields import ListOrDjangoRelatedManagerField
+from flag_engine.utils.marshmallow.fields import ListOrDjangoRelatedManagerField
+from flag_engine.utils.marshmallow.schemas import LoadToModelSchema
 
 
-class EnvironmentSchema(Schema):
+class EnvironmentSchema(LoadToModelSchema):
     id = fields.Int()
     api_key = fields.Str()
     feature_states = ListOrDjangoRelatedManagerField(
@@ -15,12 +16,16 @@ class EnvironmentSchema(Schema):
         metadata={"filter_kwargs": {"feature_segment_id": None, "identity_id": None}},
     )
     project = fields.Nested(ProjectSchema)
-
     segment_config = fields.Nested(IntegrationSchema, required=False, allow_none=True)
     heap_config = fields.Nested(IntegrationSchema, required=False, allow_none=True)
     mixpanel_config = fields.Nested(IntegrationSchema, required=False, allow_none=True)
     amplitude_config = fields.Nested(IntegrationSchema, required=False, allow_none=True)
 
-    @post_load()
-    def make_environment(self, data: dict, **kwargs) -> EnvironmentModel:
-        return EnvironmentModel(**data)
+    class Meta:
+        model_class = EnvironmentModel
+
+    @pre_dump()
+    def add_segment_overrides(self, obj, *args, **kwargs):
+        if hasattr(obj, "feature_states"):
+            obj.segment_overrides = obj.feature_states
+        return obj
