@@ -8,3 +8,7 @@ class OrganisationModel:
     feature_analytics: bool
     stop_serving_flags: bool
     persist_trait_data: bool
+
+    @property
+    def unique_slug(self):
+        return str(self.id) + "-" + self.name
